<?php
/**
 * $Horde: jonah/stories/share.php,v 1.16 2006/03/27 19:53:56 chuck Exp $
 *
 * Copyright 2004-2006 Jon Parise <jon@horde.org>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://cvs.horde.org/co.php/jonah/LICENSE.
 */

function _mail($story_part, $from, $recipients, $subject, $note)
{
    global $conf;

    require_once 'Horde/MIME.php';
    require_once 'Horde/MIME/Headers.php';
    require_once 'Horde/MIME/Message.php';

    /* Create a new MIME message object. */
    $message = new MIME_Message();

    /* If a note has been provided, add it to the message as a text part. */
    if (strlen($note) > 0) {
        $message_note = new MIME_Part('text/plain');
        $message_note->setContents($message_note->replaceEOL($note));
        $message_note->setDescription(_("Note"));
        $message->addPart($message_note);
    }

    /* Get the story as a MIME message and add its parts to our message. */
    if (count($story_part->getParts())) {
        foreach ($story_part->getParts() as $part) {
            $message->addPart($part);
        }
    } else {
        $message->addPart($story_part);
    }

    /* Build the message's MIME headers. */
    $headers = new MIME_Headers();
    $headers->addHeader('From', MIME::encodeAddress($from));
    $headers->addHeader('To', MIME::encodeAddress($recipients));
    $headers->addHeader('Subject', MIME::encode($subject, NLS::getCharset()));
    $headers->addMIMEHeaders($message);

    /* Encode the message headers. */
    $headers = $message->encode($headers->toArray(), null);

    /* Log the pending outbound message. */
    Horde::logMessage(sprintf('<%s> is sending "%s" to (%s)',
                              $from, $subject, $recipients),
                      __FILE__, __LINE__, PEAR_LOG_INFO);

    /* Send the message and return the result. */
    return $message->send($recipients, $headers);
}

$session_control = 'readonly';
@define('AUTH_HANDLER', true);
@define('JONAH_BASE', dirname(__FILE__) . '/..');
require_once JONAH_BASE . '/lib/base.php';
require_once JONAH_BASE . '/lib/News.php';
require_once 'Horde/Form.php';
require_once 'Horde/Form/Renderer.php';
require_once 'Horde/Variables.php';

$news = &Jonah_News::singleton();

/* Set up the form variables. */
$vars = Variables::getDefaultVariables();
$channel_id = $vars->get('channel_id');
$story_id = $vars->get('story_id');

if (!$conf['sharing']['allow']) {
    $url = Horde::applicationUrl('stories/view.php', true);
    $url = Util::addParameter($url, array('story_id' => $story_id, 'channel_id' => $channel_id));
    header('Location: ' . $url);
    exit;
}

$story = $news->getStory($channel_id, $story_id);
if (is_a($story, 'PEAR_Error')) {
    $notification->push(sprintf(_("Error fetching story: %s"), $story->getMessage()), 'horde.warning');
    $story = '';
}
$vars->set('subject', $story['story_title']);

/* Set up the form. */
$form = new Horde_Form($vars);
$title = _("Share Story");
$form->setTitle($title);
$form->setButtons(_("Send"), true);
$form->addHidden('', 'channel_id', 'int', false);
$form->addHidden('', 'story_id', 'int', false);
$form->addVariable(_("From"), 'from', 'email', true, false);
$form->addVariable(_("Recipients"), 'recipients', 'email', true, false, _("Separate multiple email addresses with commas."), true);
$form->addVariable(_("Subject"), 'subject', 'text', true);
$form->addVariable(_("Include"), 'include', 'enum', true, false, null, array(array(_("A link to the story"), _("The complete text of the story"))));
$form->addVariable(_("Message"), 'message', 'longtext', false, false, null, array(4, 40));

if ($form->validate($vars)) {
    $form->getInfo($vars, $info);

    $channel = $news->getChannel($channel_id);
    if (empty($channel['channel_story_url'])) {
        $story_url = Horde::applicationUrl('stories/view.php', true);
        $story_url = Util::addParameter($story_url, array('channel_id' => '%c', 'story_id' => '%s'));
    } else {
        $story_url = $channel['channel_story_url'];
    }

    $story_url = str_replace(array('%25c', '%25s'), array('%c', '%s'), $story_url);
    $story_url = str_replace(array('%c', '%s', '&amp;'), array($channel_id, $story['story_id'], '&'), $story_url);

    if ($info['include'] == 0) {
        require_once 'Horde/MIME/Part.php';

        /* TODO: Create a "URL link" MIME part instead. */
        $message_part = new MIME_Part('text/plain');
        $message_part->setContents($message_part->replaceEOL($story_url));
        $message_part->setDescription(_("Story Link"));
    } else {
        $message_part = &Jonah_News::getStoryAsMessage($story);
    }

    $result = _mail($message_part, $info['from'], $info['recipients'],
                    $info['subject'], $info['message']);

    if (is_a($result, 'PEAR_Error')) {
        $notification->push(sprintf(_("Unable to send story: %s"), $result->getMessage()), 'horde.error');
    } else {
        $notification->push(_("The story was sent successfully."), 'horde.success');
        header('Location: ' . $story_url);
        exit;
    }
}

/* Filter and prepare story content. */
$story['story_title'] = htmlspecialchars($story['story_title']);
$story['story_desc'] = htmlspecialchars($story['story_desc']);
if ($story['story_body_type'] == 'text') {
    require_once 'Horde/Text/Filter.php';
    $story['story_body'] = Text_Filter::filter($story['story_body'], 'text2html', array('parselevel' => TEXT_HTML_MICRO, 'class' => null));
}

$template = new Horde_Template();
$template->set('story', $story, true);
$template->set('main', Util::bufferOutput(array($form, 'renderActive'), new Horde_Form_Renderer(), $vars, 'share.php', 'post'));
$template->set('notify', Util::bufferOutput(array($notification, 'notify'), array('listeners' => 'status')));

require JONAH_TEMPLATES . '/common-header.inc';
echo $template->fetch(JONAH_TEMPLATES . '/stories/share.html');
require $registry->get('templates', 'horde') . '/common-footer.inc';
